# A class to ensure group and user creation completes 
# without errors.  It ensures a users required groups are 
# created and preffered shell is installed before the 
# user is created.
#
# @summary Controls ordering of group and user creation.
#
# @param required_users Hash[String, Hash[String, Variant[String, Boolean, Integer, Array[String]]]]
#   A hash of the users to be created with a nested hash 
#   containing all their parameters.
#
# @param shell_package_map Hash[String, String]
#   A hash that contains mappings for shell paths to shell package names.
#
# @param required_groups Hash[String, Hash[String, String]]
#   A hash of the groups to be created with a nested hash
#   containing all their parameters.
# 
# @example
#   include account_management
class account_management (
Hash[String, Hash[String, Variant[String, Boolean, Integer, Array[String]]]] $required_users = {},
Hash[String, String] $shell_package_map = {},
Hash[String, Hash[String, String]] $required_groups = {},
){

  contain account_management::groups
  contain account_management::users
  contain account_management::shells

  # Make sure everything happens in the correct order.
  Class['account_management::groups']
  -> Class['account_management::shells']
  -> Class['account_management::users']
}
